@@ -666,7 +666,18 @@ def orphans(args):
     util.requires_package("deborphan")
     perform.execute("deborphan", teach=args.teach, noop=args.noop)
 
+# PASSWORDS
+    
+def passwords(args):
+    """Generate a list of good passwords"""
+    command = "cat /dev/urandom | tr -cd '[:graph:]' | head -c 20; echo"
+    perform.execute(command, teach=args.teach, noop=args.noop)
+    if not args.noop:
+        for i in range(1, int(args.number)):
+            perform.execute(command)
 
+# POLICY
+    
 def policy(args):
     """From preferences file show priorities/policy (available)"""
     perform.execute("apt-cache policy " + " ".join(args.packages), teach=args.teach, noop=args.noop)
@@ -892,6 +903,7 @@ def searchapt(args):
     command = "netselect-apt " + args.dist
     perform.execute(command, teach=args.teach, noop=args.noop)
 
+# SHOW
 
 def show(args):
     """Provide a detailed description of package"""
@@ -900,18 +912,21 @@ def show(args):
     command = "{} show {}".format(tool, package_names)
     perform.execute(command, teach=args.teach, noop=args.noop)
 
+# START
 
 def start(args):
     """Start system daemons (see LIST-DAEMONS for available daemons)"""
     command = "/usr/sbin/service {} start".format(args.daemon)
     perform.execute(command, root=True, teach=args.teach, noop=args.noop)
 
+# STOP
 
 def stop(args):
     """Stop system daemons (see LISTDAEMONS for available daemons)"""
     command = "/usr/sbin/service {} stop".format(args.daemon)
     perform.execute(command, root=True, teach=args.teach, noop=args.noop)
 
+# SIZES
 
 def sizes(args):
     """Display installed sizes of given packages
@@ -921,11 +936,13 @@ def sizes(args):
     """
     util.sizes(args.packages)
 
+# SNAPSHOT
 
 def snapshot(args):
     """Generates a list of package=version for all installed packages"""
     util.do_status([], snapshot=True)
 
+# SOURCE
 
 def source(args):
     """Retrieve and unpack sources for the named packages"""
@@ -938,8 +955,9 @@ def source(args):
 def status(args):
     """Show the version and available versions of packages (with regexp support)"""
     pkgs = []
+    regexp = set('.^$*+?{},\[]|()')
     for p in args.pattern:
-        notregexp = not any((c in set('.*+') for c in p))
+        notregexp = not any((c in regexp for c in p))
         if notregexp:
             pkgs.append(p)
         else:
